@@ -85,6 +85,9 @@ on_control_ready (GvcMixerControl *control,
 		warning_dialog = NULL;
 	}
 
+        if (dialog)
+                return;
+
         dialog = GTK_WIDGET (gvc_mixer_dialog_new (control));
         g_signal_connect (dialog,
                           "response",
@@ -115,7 +118,7 @@ warning_dialog_answered (GtkDialog *d,
 static gboolean
 dialog_popup_timeout (gpointer data)
 {
-	warning_dialog = gtk_message_dialog_new (NULL,
+	warning_dialog = gtk_message_dialog_new (GTK_WINDOW(dialog),
 						 0,
 						 GTK_MESSAGE_INFO,
 						 GTK_BUTTONS_CANCEL,
@@ -130,6 +133,18 @@ dialog_popup_timeout (gpointer data)
 	return FALSE;
 }
 
+static void
+on_control_connecting (GvcMixerControl *control,
+                       UniqueApp       *app)
+{
+        if (popup_id != 0)
+                return;
+
+        popup_id = g_timeout_add_seconds (DIALOG_POPUP_TIMEOUT,
+                                          dialog_popup_timeout,
+                                          NULL);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -175,17 +190,17 @@ main (int argc, char **argv)
         gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            ICON_DATA_DIR);
 
-        control = gvc_mixer_control_new ();
+        control = gvc_mixer_control_new ("GNOME Volume Control Dialog");
+        g_signal_connect (control,
+                          "connecting",
+                          G_CALLBACK (on_control_connecting),
+                          app);
         g_signal_connect (control,
                           "ready",
                           G_CALLBACK (on_control_ready),
                           app);
         gvc_mixer_control_open (control);
 
-        popup_id = g_timeout_add_seconds (DIALOG_POPUP_TIMEOUT,
-        				  dialog_popup_timeout,
-        				  NULL);
-
         gtk_main ();
 
         if (control != NULL) {
